AudioMime enum
Values
- mp3 → const AudioMime
-
const AudioMime('http-get:*:audio/mp3:*') - mp4 → const AudioMime
-
const AudioMime('http-get:*:audio/mp4:*') - mpeg → const AudioMime
-
const AudioMime('http-get:*:audio/mpeg:*') - xFlac → const AudioMime
-
const AudioMime('http-get:*:audio/x-flac:*') - mpegurl → const AudioMime
-
const AudioMime('http-get:*:audio/mpegurl:*') - wav → const AudioMime
-
const AudioMime('http-get:*:audio/wav:*') - wma → const AudioMime
-
const AudioMime('http-get:*:audio/wma:*') - xMatroska → const AudioMime
-
const AudioMime('http-get:*:audio/x-matroska:*') - xApe → const AudioMime
-
const AudioMime('http-get:*:audio/x-ape:*') - any → const AudioMime
-
const AudioMime('http-get:*:*:*')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - protocolInfo → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited