VideoMime enum
Values
- mpeg → const VideoMime
-
const VideoMime('http-get:*:video/mpeg:*') - mp4 → const VideoMime
-
const VideoMime('http-get:*:video/mp4:*') - xMatroska → const VideoMime
-
const VideoMime('http-get:*:video/x-matroska:*') - quicktime → const VideoMime
-
const VideoMime('http-get:*:video/quicktime:*') - xMsWmv → const VideoMime
-
const VideoMime('http-get:*:video/x-ms-wmv:*') - avi → const VideoMime
-
const VideoMime('http-get:*:video/avi:*') - flv → const VideoMime
-
const VideoMime('http-get:*:video/flv:*') - ts → const VideoMime
-
const VideoMime('http-get:*:video/mp2t:*') - hls → const VideoMime
-
const VideoMime('http-get:*:application/vnd.apple.mpegurl:*') - any → const VideoMime
-
const VideoMime('http-get:*:*:*')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - protocolInfo → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited